@@ -1,9 +1,9 @@
 use strict;
 use warnings;
-package Task::Kensho::Config; # git description: v0.38-48-gdb8e27c
+package Task::Kensho::Config; # git description: v0.39-48-ga5370c5
 # ABSTRACT: A Glimpse at an Enlightened Perl: Config Modules
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 __END__
 
@@ -17,7 +17,7 @@ Task::Kensho::Config - A Glimpse at an Enlightened Perl: Config Modules
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 SYNOPSIS
 
@@ -117,7 +117,7 @@ Chris Prather <chris@prather.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Rick Leir
+=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Olaf Alders Dan Book Rachel Kelly Shawn Sorichetti Rick Leir
 
 =over 4
 
@@ -135,6 +135,22 @@ Chris Nehren <apeiron@cpan.org>
 
 =item *
 
+Olaf Alders <olaf@wundersolutions.com>
+
+=item *
+
+Dan Book <grinnz@gmail.com>
+
+=item *
+
+Rachel Kelly <rkellyalso@gmail.com>
+
+=item *
+
+Shawn Sorichetti <shawn@coloredblocks.com>
+
+=item *
+
 Rick Leir <rleir@leirtech.com>
 
 =back
